# {{ project_name }} environment configuration
MODEL_NAME={{ model_name }}
SYSTEM_PROMPT=You are a helpful assistant.

# Provider API keys (uncomment and fill in as needed)
# OPENAI_API_KEY=sk-...
# CLAUDE_API_KEY=sk-ant-...
# GOOGLE_API_KEY=...
